#!/bin/ksh
# Licensed Materials - Property of IBM
# Restricted Materials of IBM
#
# Copyright IBM Corp. 2006 All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
# Release Name: omsap_620
#
#  Description: Copy the patch xml file into the depot
#               so that the remote deploy GUI panel is updated.
#
#  Parameters:
#    CANDLEHOME, set in the environment
#
#  Returns:
#    None
#============================================================
#set -x

PATCHID=6.2.0-TIV-ITM_SAP-IF0013
XML_SRC=sa_dd_062000013.xml
XML_DST=sa_dd_062000013.xml
XML_DEPOT=sa_dd_062000000.xml
SA_PROP=sa_dd.properties

# ask for the ITM 6.2 install directory if not in the environment
if [ ! -d $CANDLEHOME/config ]; then
  while true
  do
    echo "Enter the path of the IBM Tivoli Monitoring directory or q to quit:"
    read CANDLEHOME
    if [ "${CANDLEHOME}" = "q"  ]; then
      echo "ksa_patchdepot.sh exiting..."
      exit 100
    fi
    if [ -d $CANDLEHOME/config ]; then
      export CANDLEHOME
      break
    else
      echo "ERROR: $CANDLEHOME/config was not found..."
    fi
  done
fi

# Make sure the source files are in the current running directory
if [[ ! -f $XML_SRC || ! -f $SA_PROP ]]; then
  echo "$XML_SRC or $SA_PROP was not found..."
  echo "You must run ksa_patchdepot.sh from the extracted $PATCHID directory..."
  echo "ksa_patchdepot.sh exiting..."
  exit 100
fi
cwd=`pwd`

echo "Are you sure you want to patch the depot for $PATCHID, enter (y/n):"
read ANS
if [ "$ANS" != "y"  ]; then
  echo "ksa_patchdepot.sh exiting..."
  exit 100
fi

# cd to the destination directory and do the copies
cd $CANDLEHOME/tables
FILES=`find . -name $XML_DEPOT -type f -print`
for file in $FILES
do
  echo "Modifying $CANDLEHOME/tables/$HOSTNAME/depot/PACKAGES/${file%/*}/$XML_DST"
  cp $cwd/$XML_SRC ${file%/*}/$XML_DST
#$file
  echo "Modifying $CANDLEHOME/tables/$HOSTNAME/depot/PACKAGES/${file%/*}/$SA_PROP"
  cp $cwd/$SA_PROP ${file%/*}/$SA_PROP
done

cd $CANDLEHOME
echo "ksa_patchdepot.sh completed..."

exit 0
